/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser.test.clazz.group;

import java.io.File;

import java.util.ArrayList;
import java.util.List;

/**
 * @author Peter Yoo
 */
public abstract class BaseTestClassGroup {

	public List<BaseTestClass> getTestClasses() {
		return testClasses;
	}

	public List<File> getTestClassFiles() {
		List<File> testClassFiles = new ArrayList<>();

		for (BaseTestClass testClass : testClasses) {
			testClassFiles.add(testClass.getFile());
		}

		return testClassFiles;
	}

	public static class BaseTestClass implements Comparable<BaseTestClass> {

		@Override
		public int compareTo(BaseTestClass testClass) {
			if (testClass == null) {
				throw new NullPointerException("Test class is NULL");
			}

			return _file.compareTo(testClass.getFile());
		}

		protected BaseTestClass(File file) {
			_file = file;
		}

		protected void addTestMethod(BaseTestMethod testMethod) {
			_testMethods.add(testMethod);
		}

		protected void addTestMethod(String methodName) {
			addTestMethod(new BaseTestMethod(methodName, this));
		}

		protected File getFile() {
			return _file;
		}

		protected List<BaseTestMethod> getTestMethods() {
			return _testMethods;
		}

		private final File _file;
		private final List<BaseTestMethod> _testMethods = new ArrayList<>();

	}

	public static class BaseTestMethod {

		protected BaseTestMethod(String name, BaseTestClass testClass) {
			_name = name;
			_testClass = testClass;
		}

		protected String getName() {
			return _name;
		}

		protected BaseTestClass getTestClass() {
			return _testClass;
		}

		private final String _name;
		private final BaseTestClass _testClass;

	}

	protected void addTestClass(BaseTestClass testClass) {
		testClasses.add(testClass);
	}

	protected final List<BaseTestClass> testClasses = new ArrayList<>();

}